@@ -315,7 +315,7 @@ void Kontrast::gotColorResponse(uint response, const QVariantMap &results)
 #endif
 }
 
-Kontrast::ContrastQualities Kontrast::getContrastQualities()
+Kontrast::ContrastQualities Kontrast::getContrastQualities() const
 {
     const qreal contrast = Kontrast::contrast();
 
@@ -357,3 +357,5 @@ QString Kontrast::getFontSizeQualityLabel()
     }
     return fontSizeQualityLabel;
 }
+
+#include "moc_kontrast.cpp"
